@@ -1,9 +1,9 @@
 
 -- CLEAR curse: clears the whole map -----------------------------------------
 
-ID_CURSE_CLEAR=1
+ID_CURSE_CLEAR=3
 
-function do_curse_clear()
-    clear_map()
+function clear_do_curse()
+    utils_clear_map()
 end
 
