@@ -1,12 +1,12 @@
 
 -- various functions used for pattern matching -------------------------------
 
-function shift_column_down(x_col,y_bottom)
+function utils_shift_column_down(x_col,y_bottom)
     local y
     local color
 
     y=y_bottom
-    while y>1 do
+    while y>=1 do
         color=u61_get_square_color(x_col,y-1)
         u61_set_square_color(x_col,y,color)
         y=y-1
@@ -19,16 +19,9 @@ function shift_column_down(x_col,y_bottom)
 end
 
 
-
-
-
-
-
-
-
 -- Functions used in many curse scripts --------------------------------------
 
-function shift_map_up()
+function utils_shift_map_up()
     local x
     local y
     local width
@@ -51,7 +44,7 @@ function shift_map_up()
     u61_set_curse_y(u61_get_curse_y()-1)
 end
 
-function clear_map()
+function utils_clear_map()
     local x
     local y
     local width
